@@ -15,7 +15,7 @@ import numpy as np
 import torch
 from loguru import logger as log
 
-from graphein.utils.utils import import_message
+from graphein.utils.dependencies import import_message
 
 try:
     import torch
