@@ -19,7 +19,7 @@ from graphein.protein.features.sequence.utils import (
     compute_feature_over_chains,
     subset_by_node_feature_value,
 )
-from graphein.utils.utils import import_message
+from graphein.utils.dependencies import import_message
 
 try:
     import torch
@@ -39,6 +39,7 @@ except ImportError:
         submodule="graphein.protein.features.sequence.embeddings",
         package="biovec",
         pip_install=True,
+        extras=True,
     )
     log.warning(message)
 
