@@ -101,7 +101,7 @@ class Protein(Data):
 
         # From a PyG Data object
         data = gpt.io.protein_to_pyg(
-            pdb_code="4hhb", # Can alternatively pass a path or a uniprot ID (for AF2) with pdb_path=... and uniprot_id=...
+            pdb_code="4hhb", # Can alternatively pass a path or a uniprot ID (for AF2) with path=... and uniprot_id=...
             chain_selection="ABCD", # Select all 4 chains
             deprotonate=True, # Deprotonate the structure
             keep_insertions=False, # Remove insertions
@@ -194,7 +194,7 @@ class Protein(Data):
         :rtype: Protein
         """
         self.id = id
-        self.x = protein_df_to_tensor(
+        self.coords = protein_df_to_tensor(
             df, atoms_to_keep=atoms_to_keep, fill_value=self.fill_value
         )
         self.residues = get_sequence(
@@ -225,7 +225,7 @@ class Protein(Data):
             >>> import graphein.protein.tensor as gpt
 
             >>> data = gpt.io.protein_to_pyg(
-                ... pdb_code="4hhb", # Can alternatively pass a path or a uniprot ID (for AF2) with pdb_path=... and uniprot_id=...
+                ... pdb_code="4hhb", # Can alternatively pass a path or a uniprot ID (for AF2) with path=... and uniprot_id=...
                 ... chain_selection="ABCD", # Select all 4 chains
                 ... deprotonate=True, # Deprotonate the structure
                 ... keep_insertions=False, # Remove insertions
@@ -279,7 +279,7 @@ class Protein(Data):
 
         .. see:: :func:`graphein.protein.tensor.io.to_dataframe`
 
-        :param x: AtomTensor, defaults to ``None`` (uses ``Protein.x``)
+        :param x: AtomTensor, defaults to ``None`` (uses ``Protein.coords``)
         :type x: Optional[Union[AtomTensor, BackboneTensor]], optional
         :param cache: Whether to store the dataframe as a ``Protein`` attribute,
             defaults to ``None``.
@@ -291,7 +291,7 @@ class Protein(Data):
         """
 
         if x is None:
-            x = self.x
+            x = self.coords
         out = to_dataframe(
             x=x,
             fill_value=self.fill_value,
@@ -328,7 +328,7 @@ class Protein(Data):
         .. seealso:: :meth:`graphein.protein.tensor.io.to_dataframe`
 
 
-        :param x: ``AtomTensor``, defaults to ``None`` (uses ``Protein.x``)
+        :param x: ``AtomTensor``, defaults to ``None`` (uses ``Protein.coords``)
         :type x: Optional[Union[AtomTensor, BackboneTensor]], optional
         :param out_path: Path to output file, defaults to ``None``
             (``{Protein.id}.pdb``)
@@ -341,7 +341,7 @@ class Protein(Data):
         if out_path is None:
             out_path = self.id + ".pdb"
         if x is None:
-            x = self.x
+            x = self.coords
         to_pdb(x, out_path, gz, **kwargs)
 
     def from_pdb_code(
@@ -376,7 +376,7 @@ class Protein(Data):
 
     def from_pdb_file(
         self,
-        pdb_path: str,
+        path: str,
         chain_selection: str = "all",
         deprotonate: bool = True,
         keep_insertions=False,
@@ -387,7 +387,7 @@ class Protein(Data):
         graph_labels: Optional[torch.Tensor] = None,
     ) -> "Protein":
         data = protein_to_pyg(
-            pdb_path=pdb_path,
+            path=path,
             chain_selection=chain_selection,
             deprotonate=deprotonate,
             keep_insertions=keep_insertions,
@@ -501,7 +501,7 @@ class Protein(Data):
         :rtype: graphein.protein.tensor.types.CoordTensor
         """
 
-        out = get_c_alpha(self.x)
+        out = get_c_alpha(self.coords)
         if cache is not None:
             setattr(self, cache, out)
         return out
@@ -529,7 +529,7 @@ class Protein(Data):
         :return: Backbone coordinates ``[Length x 4 x 3]``
         :rtype: graphein.protein.tensor.types.BackboneTensor
         """
-        out = get_backbone(self.x)
+        out = get_backbone(self.coords)
         if cache is not None:
             setattr(self, cache, out)
         return out
@@ -549,7 +549,7 @@ class Protein(Data):
         :return: _description_
         :rtype: Tuple[BackboneFrameTensor, CoordTensor]
         """
-        out = get_backbone_frames(self.x)
+        out = get_backbone_frames(self.coords)
         if cache is not None:
             setattr(self, cache, out)
         return out
@@ -578,7 +578,7 @@ class Protein(Data):
         :rtype: AtomTensor
         """
         if x is None:
-            x = self.x
+            x = self.coords
         return idealize_backbone(x, lr=lr, n_iter=n_iter, inplace=inplace)
 
     def full_atom_coords(self, cache: Optional[str] = None) -> CoordTensor:
@@ -593,7 +593,7 @@ class Protein(Data):
         :return: Tensor of atom positions.
         :rtype: CoordTensor
         """
-        out = get_full_atom_coords(self.x, fill_value=self.fill_value)
+        out = get_full_atom_coords(self.coords, fill_value=self.fill_value)
         if cache is not None:
             setattr(self, cache, out)
         return out
@@ -605,7 +605,7 @@ class Protein(Data):
         """
         .. see:: :func:`graphein.protein.tensor.angles.dihedrals`
         """
-        out = dihedrals(self.x, rad=rad, embed=embed)
+        out = dihedrals(self.coords, rad=rad, embed=embed)
 
         if cache is not None:
             setattr(self, cache, out)
@@ -622,7 +622,7 @@ class Protein(Data):
             , (not stored).
         :type cache: Optional[str]
         """
-        return sidechain_torsion(self.x, self.residues)
+        return sidechain_torsion(self.coords, self.residues)
 
     def kappa(
         self,
@@ -640,7 +640,7 @@ class Protein(Data):
             (not stored).
         :type cache: Optional[str]
         """
-        out = kappa(self.x, rad=rad, embed=embed)
+        out = kappa(self.coords, rad=rad, embed=embed)
         if cache is not None:
             setattr(self, cache, out)
         return out
@@ -658,7 +658,7 @@ class Protein(Data):
             (not stored).
         :type cache: Optional[str]
         """
-        out = alpha(self.x, rad=rad, embed=embed)
+        out = alpha(self.coords, rad=rad, embed=embed)
         if cache is not None:
             setattr(self, cache, out)
         return out
@@ -677,8 +677,8 @@ class Protein(Data):
 
         """
         out = kabsch(
-            self.x,
-            other.x,
+            self.coords,
+            other.coords,
             ca_only=ca_only,
             fill_value=self.fill_value,
             return_transformed=return_transformed,
@@ -710,7 +710,7 @@ class Protein(Data):
             complete structure.
         :rtype: bool
         """
-        return is_complete_structure(self.x, self.residues)
+        return is_complete_structure(self.coords, self.residues)
 
     def has_complete_backbone(self) -> bool:
         """
@@ -722,7 +722,7 @@ class Protein(Data):
             complete backbone.
         :rtype: bool
         """
-        return has_complete_backbone(self.x)
+        return has_complete_backbone(self.coords)
 
     def __eq__(self, __o: object) -> bool:
         # sourcery skip: merge-duplicate-blocks, merge-else-if-into-elif
@@ -755,7 +755,7 @@ class Protein(Data):
 
     def plot_dihedrals(self) -> go.Figure:
         dh = (
-            dihedrals(self.x)
+            dihedrals(self.coords)
             if "dihedrals" not in self.keys
             else self.dihedrals
         )
@@ -781,7 +781,7 @@ class Protein(Data):
         """
         residue_ids = self.residue_id if hasattr(self, "residue_id") else None
         return plot_structure(
-            self.x, atoms=atoms, lines=lines, residue_ids=residue_ids
+            self.coords, atoms=atoms, lines=lines, residue_ids=residue_ids
         )
 
     def apply_structural_noise(
@@ -798,13 +798,13 @@ class Protein(Data):
         .. see:: :func:`graphein.protein.tensor.geometry.apply_structural_noise`
 
         :param x: Coordinates to apply noise to, defaults to ``None``. If
-            ``None`` (default), ``self.x`` is used.
+            ``None`` (default), ``self.coords`` is used.
         :param cache: If provided, the result will be cached in the ``Protein``
             under the provided string as the attribute name. Default is ``None``,
             (not stored).
         """
         if x is None:
-            x = self.x
+            x = self.coords
         out = apply_structural_noise(
             x,
             magnitude=magnitude,
@@ -836,6 +836,9 @@ class ProteinBatch(Batch):
         if hasattr(batch, "_inc_dict"):
             self._inc_dict = batch._inc_dict
 
+        if hasattr(batch, "_num_graphs"):
+            self._num_graphs = batch._num_graphs
+
         # self.fill_value = fill_value
         return self
 
@@ -844,8 +847,6 @@ class ProteinBatch(Batch):
         # sourcery skip: class-extract-method
         proteins = [Protein().from_data(p) for p in proteins]
         batch = Batch.from_data_list(proteins)
-        # self.from_batch(batch)
-        # return self
         return cls().from_batch(batch)
 
     def from_pdb_codes(
@@ -886,7 +887,7 @@ class ProteinBatch(Batch):
 
     def from_pdb_files(
         self,
-        pdb_paths: List[str],
+        paths: List[str],
         chain_selection: Optional[List[str]] = None,
         node_labels: Optional[List[torch.Tensor]] = None,
         graph_labels: Optional[List[torch.Tensor]] = None,
@@ -898,7 +899,7 @@ class ProteinBatch(Batch):
     ):
         proteins = [
             Protein().from_pdb_file(
-                pdb_path=pdb,
+                path=pdb,
                 chain_selection=chain_selection[i]
                 if chain_selection is not None
                 else "all",
@@ -914,7 +915,7 @@ class ProteinBatch(Batch):
                 if graph_labels is not None
                 else None,
             )
-            for i, pdb in enumerate(pdb_paths)
+            for i, pdb in enumerate(paths)
         ]
         batch = Batch.from_data_list(proteins)
         self.from_batch(batch)
@@ -960,7 +961,7 @@ class ProteinBatch(Batch):
         :rtype: graphein.protein.tensor.types.CoordTensor
         """
 
-        out = get_c_alpha(self.x)
+        out = get_c_alpha(self.coords)
         if cache is not None:
             setattr(self, cache, out)
         return out
@@ -986,7 +987,7 @@ class ProteinBatch(Batch):
         :return: Backbone coordinates ``[Length x 4 x 3]``
         :rtype: graphein.protein.tensor.types.BackboneTensor
         """
-        out = get_backbone(self.x)
+        out = get_backbone(self.coords)
         if cache is not None:
             setattr(self, cache, out)
         return out
@@ -1006,7 +1007,7 @@ class ProteinBatch(Batch):
         :return: _description_
         :rtype: Tuple[BackboneFrameTensor, CoordTensor]
         """
-        out = get_backbone_frames(self.x)
+        out = get_backbone_frames(self.coords)
         if cache is not None:
             setattr(self, cache, out)
         return out
@@ -1064,7 +1065,7 @@ class ProteinBatch(Batch):
 
     # Testing
     def is_complete(self) -> bool:
-        return is_complete_structure(self.x, self.residues)
+        return is_complete_structure(self.coords, self.residues)
 
     def has_complete_backbone(self) -> bool:
         """Returns ``True`` if the protein has a complete backbone, else
@@ -1076,7 +1077,7 @@ class ProteinBatch(Batch):
 
             :meth:`graphein.protein.tensor.testing.has_complete_backbone`
         """
-        return has_complete_backbone(self.x, fill_value=self.fill_value)
+        return has_complete_backbone(self.coords, fill_value=self.fill_value)
 
     def protein_apply(
         self, func: Callable[["Protein"], Any], rebatch: bool = False
@@ -1094,7 +1095,7 @@ class ProteinBatch(Batch):
                 )
 
             def single_plot(protein: gpt.Protein()):
-                return plot_structure(protein.x, lines=False)
+                return plot_structure(protein.coords, lines=False)
 
             plots = batch.protein_apply(single_plot)
             plots[2]
@@ -1132,7 +1133,7 @@ class ProteinBatch(Batch):
             from graphein.protein.tensor.plot import plot_structure
 
             def single_plot(protein: gpt.Protein()):
-            return plot_structure(protein.x, lines=False)
+            return plot_structure(protein.coords, lines=False)
 
             plot = batch.apply_to(single_plot, 2)
 
@@ -1277,13 +1278,13 @@ class ProteinBatch(Batch):
         .. see:: :func:`graphein.protein.tensor.geometry.apply_structural_noise`
 
         :param x: Coordinates to apply noise to, defaults to ``None``. If
-            ``None`` (default), ``self.x`` is used.
+            ``None`` (default), ``self.coords`` is used.
         :param cache: If provided, the result will be cached in the
             ``ProteinBatch`` under the provided string as the attribute name.
             Default is ``None``, (not stored).
         """
         if x is None:
-            x = self.x
+            x = self.coords
         out = apply_structural_noise(
             x,
             magnitude=magnitude,
@@ -1296,7 +1297,7 @@ class ProteinBatch(Batch):
 
 
 def to_protein(
-    pdb_path: Optional[str] = None,
+    path: Optional[str] = None,
     pdb_code: Optional[str] = None,
     uniprot_id: Optional[str] = None,
     chain_selection: str = "all",
@@ -1320,7 +1321,7 @@ def to_protein(
         gpt.data.to_protein(pdb_code="3eiy", ...)
 
         # From PDB Path
-        gpt.io.to_protein(pdb_path="3eiy.pdb", ...)
+        gpt.io.to_protein(path="3eiy.pdb", ...)
 
         # From UniProt ID
         gpt.io.to_protein(uniprot_id="Q5VSL9", ...)
@@ -1331,7 +1332,7 @@ def to_protein(
         :func:`graphein.protein.tensor.data.to_protein_mp`
 
 
-    :param pdb_path: Path to PDB file. Default is ``None``.
+    :param path: Path to PDB or MMTF file. Default is ``None``.
     :param pdb_code: PDB accesion code. Default is ``None``.
     :param uniprot_id: UniProt ID. Default is ``None``.
     :param chain_selection: Selection of chains to include (e.g. ``"ABC"``) or
@@ -1348,7 +1349,7 @@ def to_protein(
     :rtype: Protein
     """
     data = protein_to_pyg(
-        pdb_path=pdb_path,
+        path=path,
         pdb_code=pdb_code,
         uniprot_id=uniprot_id,
         chain_selection=chain_selection,
@@ -1384,9 +1385,9 @@ def _mp_constructor(
                 pdb_code=args[0],
                 chain_selection=args[1],  # , model_index=args[2]
             )
-        elif source == "pdb_path":
+        elif source == "path":
             return func(
-                pdb_path=args[0],
+                path=args[0],
                 chain_selection=args[1],  # , model_index=args[2]
             )
         elif source == "uniprot_id":
@@ -1404,7 +1405,7 @@ def _mp_constructor(
 
 
 def to_protein_mp(
-    pdb_paths: Optional[str] = None,
+    paths: Optional[str] = None,
     pdb_codes: Optional[str] = None,
     uniprot_ids: Optional[str] = None,
     chain_selections: Optional[List[str]] = None,
@@ -1429,7 +1430,7 @@ def to_protein_mp(
         gpt.data.to_protein_mp(pdb_codes=["3eiy", "4hhb", ..., num_cores=8])
 
         # From PDB Paths
-        gpt.io.to_protein_mp(pdb_paths=["3eiy.pdb", "4hhb.pdb", ...])
+        gpt.io.to_protein_mp(paths=["3eiy.pdb", "4hhb.pdb", ...])
 
         # From UniProt IDs
         gpt.io.to_protein_mp(uniprot_ids=["Q5VSL9", ...])
@@ -1441,7 +1442,7 @@ def to_protein_mp(
         :func:`graphein.protein.tensor.data.to_protein`
 
 
-    :param pdb_paths: Path to PDB file. Default is ``None``.
+    :param paths: Path to PDB or MMTF files. Default is ``None``.
     :param pdb_codes: PDB accesion code. Default is ``None``.
     :param uniprot_ids: UniProt ID. Default is ``None``.
     :param chain_selections: Selection of chains to include (e.g. ``"ABC"``) or
@@ -1459,18 +1460,16 @@ def to_protein_mp(
     :rtype: List[Protein]
     """
     assert (
-        pdb_codes is not None
-        or pdb_paths is not None
-        or uniprot_ids is not None
+        pdb_codes is not None or paths is not None or uniprot_ids is not None
     ), "Iterable of pdb codes, pdb paths or uniprot IDs required."
 
     if pdb_codes is not None:
         pdbs = pdb_codes
         source = "pdb_code"
 
-    if pdb_paths is not None:
-        pdbs = pdb_paths
-        source = "pdb_path"
+    if paths is not None:
+        pdbs = paths
+        source = "path"
 
     if uniprot_ids is not None:
         pdbs = uniprot_ids
