@@ -1,4 +1,6 @@
-import networkx as nx
+"""Tests for graphein.ppi.graphs"""
+import bioservices
+import pytest
 
 from graphein.ppi.config import PPIGraphConfig
 from graphein.ppi.edges import add_biogrid_edges, add_string_edges
@@ -17,7 +19,20 @@ PROTEIN_LIST = [
 ]
 
 
+@pytest.mark.skip("not a test")
+def hgnc_available():
+    try:
+        a = bioservices.HGNC()
+        return True
+    except TypeError:
+        return False
+
+
+HGNC_AVAILABLE = hgnc_available()
+
+
 # Test Graph Construction
+@pytest.mark.skipif(not HGNC_AVAILABLE, reason="HGNC not available")
 def test_construct_graph():
     config = PPIGraphConfig()
 
@@ -28,8 +43,6 @@ def test_construct_graph():
         config=config,
     )
 
-    print(nx.info(g))
-
     # Check nodes and edges
     assert len(g.nodes()) == 8
     assert len(g.edges()) == 23
@@ -37,12 +50,12 @@ def test_construct_graph():
     # Check edge types are from string/biogrid
     # Check nodes are in our list
     for u, v, d in g.edges(data=True):
-        assert d["kind"].issubset(set(["string", "biogrid"]))
+        assert d["kind"].issubset({"string", "biogrid"})
         assert u in PROTEIN_LIST
         assert v in PROTEIN_LIST
 
     # Check sequence is defined if UniProt ID found
-    for n, d in g.nodes(data=True):
+    for _, d in g.nodes(data=True):
         assert d["protein_id"] in PROTEIN_LIST
         if d["uniprot_ids"] is not None:
             for id in d["uniprot_ids"]:
